(**
 * Copyright (c) 2015, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the "hack" directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 *)

let go _ _ _ _ = Some (fun _ _ _ _ -> ())
let incremental_update _ _ _ _ = ()
let get_all_targets () = []
